summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFabio Alessandrelli <fabio.alessandrelli@gmail.com>2018-02-08 22:00:55 +0100
committerFabio Alessandrelli <fabio.alessandrelli@gmail.com>2018-02-14 01:26:34 +0100
commit9e2b1b3b009f26fc24bbf02b4b66218f00133907 (patch)
treee3aaeefab7bfc0b5df8c51f1c636a9edf1b137c6
parent6fcc8b7e1f415db55c6627630f622a37f6973714 (diff)
Disabled mbedtls module in javascript platform
-rw-r--r--platform/javascript/detect.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/platform/javascript/detect.py b/platform/javascript/detect.py
index c7acd215ae..7e6a1518ed 100644
--- a/platform/javascript/detect.py
+++ b/platform/javascript/detect.py
@@ -28,11 +28,11 @@ def get_flags():
return [
('tools', False),
('module_theora_enabled', False),
# Disabling the OpenSSL module noticeably reduces file size.
# The module has little use due to the limited networking functionality
# in this platform. For the available networking methods, the browser
# manages TLS.
- #('module_openssl_enabled', False),
+ ('module_mbedtls_enabled', False),
]
@@ -28,11 +28,11 @@ def get_flags():
('tools', False),
('module_theora_enabled', False),
- # Disabling the OpenSSL module noticeably reduces file size.
+ # Disabling the mbedtls module reduces file size.
# The module has little use due to the limited networking functionality
# in this platform. For the available networking methods, the browser